@@ -41,6 +41,7 @@ class Doxygen:
                     doc_type = self.doc_type, rel_path = self.rel_path)
             self.pages = Node('root', None, self.cache, self.parser, None, \
                     doc_type = self.doc_type, rel_path = self.rel_path)
+            
 
             for compound in xml.findall('compound'):
                 kind = Kind.from_str(compound.get('kind'))
@@ -55,7 +56,8 @@ class Doxygen:
                             doc_type = self.doc_type, rel_path = self.rel_path)
                     node._visibility = Visibility.PUBLIC
                     self.groups.add_child(node)
-                if kind == Kind.FILE or kind == Kind.DIR:
+                if kind == Kind.FILE :
+                #if kind == Kind.FILE or kind == Kind.DIR:
                     node = Node(os.path.join(index_path, refid + '.xml'), None, self.cache, self.parser, self.root, \
                             doc_type = self.doc_type, rel_path = self.rel_path)
                     node._visibility = Visibility.PUBLIC
@@ -87,6 +89,13 @@ class Doxygen:
             self.groupsnodes.append(self.groups)
             self.filesnodes.append(self.files)
             self.pagesnodes.append(self.pages)
+            #if path == "/home/gx/bbb/ccc/./XML/demuxhal/index.xml":
+            #    break
+            #if path == '/home/gx/bbb/ccc/./XML/deshal/index.xml':
+            #    break
+            #if path == '/home/gx/bbb/ccc/./XML/fehal/index.xml':
+            #    break
+
     #def get_index(self, path):
     #    if os.path.exists(os.path.join(path,'index.xml')):
     #        self.index_paths.append(path)
@@ -100,6 +109,16 @@ class Doxygen:
     #                    self.index_paths.append(os.path.join(dir_s, 'index.xml'))
     #                else:
     #                    self.get_index(dir_s)
+    def list_node(self, node, leval = 0):
+        n = leval
+        print('\t'*n, node.kind, node.name, 'now')
+        if node.has_children:
+            n += 1
+            for child in node.children:
+                print('\t'*n, child.kind, child.name, 'children')
+                if child.has_children:
+                    self.list_node(child, n)
+
 
     def get_index(self, path):
         if os.path.exists(os.path.join(path,'index.xml')):
