@@ -200,8 +200,19 @@ class GenMD():
             #    cmd = 'cp -rf \"' + os.path.join(path,mdfile) + '\" ' + \
             #            os.path.join(self.bookpath, targetdir)
             #    os.system(cmd)
-            else:
-                self.copymdfile(os.path.join(path,mdfile))
+            #else:
+            #    self.copymdfile(os.path.join(path,mdfile))
+
+    def delete_doc(self, in_path):
+        tmp = in_path.split('/')
+        new_tmp = []
+        for i in tmp:
+            if not i == 'doc':
+                new_tmp.append(i)
+        targetdir = '/'.join(new_tmp)
+        targetdir = targetdir.strip("/")
+        return targetdir
+
 
     def _touch_summary(self, md_dict):
         #fd.write('* [' + name + '](index.md)\n')
@@ -211,15 +222,18 @@ class GenMD():
             for i in md_dict.values():
                 if 'index' in i:
                     md_name = os.path.relpath(os.path.join(i['path'], 'index.md'), self.start_path)
+                    md_name = self.delete_doc(md_name)
                     fd.write('* [' + md_name + '](' + md_name + ')\n')
                     if 'files' in i:
                         for f in i['files']:
                             md_name = os.path.relpath(os.path.join(i['path'], f), self.start_path)
+                            md_name = self.delete_doc(md_name)
                             fd.write('  * [' + md_name + '](' + md_name + ')\n')
                 else:
                     if 'files' in i:
                         for f in i['files']:
                             md_name = os.path.relpath(os.path.join(i['path'], f), self.start_path)
+                            md_name = self.delete_doc(md_name)
                             fd.write('* [' + md_name + '](' + md_name + ')\n')
 
     def _touch_readme(self):
@@ -246,6 +260,7 @@ class GenMD():
         else:
             for cfgdir in self.source_paths:
                 path_msg = cfgdir.split('/doc')[1].strip('/')
+
                 md_dict[path_msg] = {
                         'path':cfgdir,
                         }
@@ -256,6 +271,7 @@ class GenMD():
                     md_dict[path_msg]['files'] = other_md_files
             self._touch_summary(md_dict)
             self._touch_readme()
+        #sys.exit()
 
     def GenMD(self, is_all):
         self.before_work()
@@ -273,9 +289,9 @@ class GenMD():
             cmd = "doxybook -i " + self.xmlpath + " -o " + self.bookpath + ' -s ' + \
                 self.bookpath + '/SUMMARY.md -t gitbook -a ' + is_all + ' -p part -l ' + docref_path
         os.system(cmd)
-        #for cfgdir in self.source_paths:
-        #    self.copymdfile(cfgdir)
-        self.copymdfile(self.start_path)
+        for cfgdir in self.source_paths:
+            self.copymdfile(cfgdir)
+        #self.copymdfile(self.start_path)
 
     def check_file(self, file_name):
         #if os.path.exists(os.path.join(self.exec_dir, self.link_path, \
