@@ -143,6 +143,16 @@ class Generator:
         }
         self._render(self.definelist_template, path, data) 
 
+    def list_node(self, node, leval = 0):
+        n = leval
+        print('\t'*n, node.kind, node.name, 'now')
+        if node.has_children:
+            n += 1
+            for child in node.children:
+                print('\t'*n, child.kind, child.name, 'children')
+                if child.has_children:
+                    self.list_node(child, n)
+
     def enumlist(self, output_dir: str, nodes: [Node]):
         path = os.path.join(output_dir, 'enumlist.md')
 
