@@ -101,6 +101,15 @@ class Node:
             pass
 
     #def node_replace(rep, replace, node):
+    def list_node(self, node, leval = 0):
+        n = leval
+        print('\t'*n, node._kind, node._name, 'now')
+        if node.has_children:
+            n += 1
+            for child in node._children:
+                print('\t'*n, child._kind, child._name, 'children')
+                if child.has_children:
+                    self.list_node(child, n)
 
     def add_child(self, child: 'Node'):
         self._children.append(child)
