@@ -7,12 +7,15 @@ from doxybook.xml_parser import XmlParser
 from doxybook.cache import Cache
 from doxybook.constants import Kind
 
-def list_node( node ):
+def list_node(node, leval = 0):
+    n = leval
+    print('\t'*n, node.kind, node.name, 'now')
     if node.has_children:
+        n += 1
         for child in node.children:
+            print('\t'*n, child.kind, child.name, 'children')
             if child.has_children:
-                list_node(child)
-            print(child.kind, child.name)
+                list_node(child, n)
 
 def run(output: str, 
         input: str, 
@@ -54,7 +57,6 @@ def run(output: str,
         if '/XML/' in v:
             xmldir = re.sub('.+/XML', '', os.path.dirname(v))
             output_dir = xmldir
-            print(output_dir)
             #if output_dir[0] == '/':
             #    output_dir = output_dir[1:]
             output_dir = output_dir.strip('/')
