@@ -5,7 +5,7 @@ Here are the macros with brief descriptions:
 
 
 {% for node in nodes recursive %}
-{%- if node.is_define and node.brief %}
+{%- if node.is_define %}
 
 * **{{node.kind.value}}** [**{{node.name_short}}**]({{node.refid+'.md'}}) {{node.brief}}
 
@@ -15,3 +15,4 @@ Here are the macros with brief descriptions:
 {%- endif -%}
 {%- endfor %}
 """
+#{%- if node.is_define and node.brief %}
